---
name: Feature request
about: Suggest a new feature
title: "Feature Request Summary"
labels: "enhancement"
---

**Is your feature request related to a problem? Please describe.**

<!-- A clear and concise description of what the problem is. Ex. I'm always frustrated when ... -->

**Describe the solution you would like**

<!-- A clear and concise description of what you want to happen. -->

**Additional context**

<!-- Add any other context or screenshots about the feature request here. -->
